from __future__ import annotations

from selector import get_indexes_from_selected
from selector import get_selected_from_items


def test_get_selected_from_items_basic():
    items = ['apple', 'banana', 'cherry']
    selected = 'banana'
    result = get_selected_from_items(items, selected)
    assert result == ['banana']


def test_get_selected_from_items_multiple():
    items = ['apple', 'banana', 'cherry']
    selected = 'banana\ncherry'
    result = get_selected_from_items(items, selected)
    assert result == ['banana', 'cherry']


def test_get_selected_from_items_empty_selection():
    items = ['apple', 'banana', 'cherry']
    selected = ''
    result = get_selected_from_items(items, selected)
    assert result == []


def test_get_selected_from_items_missing_items():
    items = []
    selected = 'apple'
    result = get_selected_from_items(items, selected)
    assert result == []


def test_get_selected_from_items_value_error():
    items = ['apple', 'banana', 'cherry']
    selected = 'orange'
    result = get_selected_from_items(items, selected)
    assert result == items


def test_get_index_from_selected_items_index():
    items = ['apple', 'banana', 'cherry']
    selected = 'banana'
    result = get_indexes_from_selected(items, selected)
    assert result == [1]


def test_get_index_from_selected_items_multiple_index():
    items = ['apple', 'banana', 'cherry']
    selected = 'banana\ncherry'
    result = get_indexes_from_selected(items, selected)
    assert result == [1, 2]


def test_get_index_from_selected_items_empty_selection():
    items = ['apple', 'banana', 'cherry']
    selected = ''
    result = get_indexes_from_selected(items, selected)
    assert result == []
